@@ -2,9 +2,10 @@
 tostplot <- function(image, ggtheme = NULL, theme = NULL) {
   ciw <- 90
 
+  # something wrong with what is being passed in the points dataframe
   data <- image$state
 
-  plot <- ggplot(data=data, aes_string(x=0, y='m')) +
+  p1 <- ggplot(data=data, aes_string(x=0, y='m')) +
     geom_hline(yintercept=data$low,  colour=theme$color[1]) +
     geom_hline(yintercept=data$high, colour=theme$color[1]) +
     geom_text(aes(5, data$low,  vjust=-.9, hjust=1), label='Lower bound', colour=theme$color[1]) +
@@ -20,5 +21,19 @@ tostplot <- function(image, ggtheme = NULL, theme = NULL) {
       axis.ticks.x=element_blank(),
       axis.title.y=element_blank(),)
 
-  suppressWarnings(print(plot))
+  suppressWarnings(print(p1))
+}
+
+
+cut_cdf_qi = function(p, .width = c(.66, .95, 1), labels = NULL) {
+  .width = sort(.width)
+
+  if (is.function(labels)) {
+    labels = labels(.width)
+  } else if (is.null(labels)) {
+    labels = .width
+  }
+
+  cut(abs(1 - p*2), labels = labels,
+      breaks = c(0, .width), include.lowest = TRUE, ordered_result = TRUE)
 }
