@@ -20,11 +20,12 @@
 #' powerTOSTtwo(alpha=0.05, N=108, statistical_power=0.8)
 #' @section References:
 #' Chow, S.-C., Wang, H., & Shao, J. (2007). Sample Size Calculations in Clinical Research, Second Edition - CRC Press Book. Formula 3.2.4 with k = 1
-#' @importFrom stats pnorm pt qnorm qt
+#' @importFrom stats pnorm pt qnorm qt power.t.test
 #' @importFrom graphics abline plot points segments title
 #' @export
 
 powerTOSTtwo<-function(alpha, statistical_power, N, low_eqbound_d, high_eqbound_d){
+  message("Note: this function is defunct. Please use power_t_TOST instead")
   if(missing(N)) {
     NT1<-2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/(low_eqbound_d)^2
     NT2<-2*(qnorm(1-alpha)+qnorm(1-((1-statistical_power)/2)))^2/(high_eqbound_d)^2
